@@ -5,8 +5,10 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/lxc/incus/internal/instance"
 	"github.com/spf13/cobra"
+
+	"github.com/lxc/incus/v6/internal/instance"
+	"github.com/lxc/incus/v6/shared/api"
 )
 
 func (g *cmdGlobal) cmpClusterGroupNames(toComplete string) ([]string, cobra.ShellCompDirective) {
@@ -290,17 +292,14 @@ func (g *cmdGlobal) cmpInstances(toComplete string) ([]string, cobra.ShellCompDi
 	if len(resources) > 0 {
 		resource := resources[0]
 
-		instances, _ := resource.server.GetInstanceNames("container")
-		vms, _ := resource.server.GetInstanceNames("virtual-machine")
-		instances = append(instances, vms...)
-
-		for _, instance := range instances {
+		instances, _ := resource.server.GetInstanceNames(api.InstanceTypeAny)
+		for _, instName := range instances {
 			var name string
 
 			if resource.remote == g.conf.DefaultRemote && !strings.Contains(toComplete, g.conf.DefaultRemote) {
-				name = instance
+				name = instName
 			} else {
-				name = fmt.Sprintf("%s:%s", resource.remote, instance)
+				name = fmt.Sprintf("%s:%s", resource.remote, instName)
 			}
 
 			results = append(results, name)
@@ -316,6 +315,46 @@ func (g *cmdGlobal) cmpInstances(toComplete string) ([]string, cobra.ShellCompDi
 	return results, cmpDirectives
 }
 
+func (g *cmdGlobal) cmpInstancesAndSnapshots(toComplete string) ([]string, cobra.ShellCompDirective) {
+	results := []string{}
+	cmpDirectives := cobra.ShellCompDirectiveNoFileComp
+
+	resources, _ := g.ParseServers(toComplete)
+
+	if len(resources) > 0 {
+		resource := resources[0]
+
+		if strings.Contains(resource.name, instance.SnapshotDelimiter) {
+			instName := strings.SplitN(resource.name, instance.SnapshotDelimiter, 2)[0]
+			snapshots, _ := resource.server.GetInstanceSnapshotNames(instName)
+			for _, snapshot := range snapshots {
+				results = append(results, fmt.Sprintf("%s/%s", instName, snapshot))
+			}
+		} else {
+			instances, _ := resource.server.GetInstanceNames(api.InstanceTypeAny)
+			for _, instName := range instances {
+				var name string
+
+				if resource.remote == g.conf.DefaultRemote && !strings.Contains(toComplete, g.conf.DefaultRemote) {
+					name = instName
+				} else {
+					name = fmt.Sprintf("%s:%s", resource.remote, instName)
+				}
+
+				results = append(results, name)
+			}
+		}
+	}
+
+	if !strings.Contains(toComplete, ":") {
+		remotes, directives := g.cmpRemotes(false)
+		results = append(results, remotes...)
+		cmpDirectives |= directives
+	}
+
+	return results, cmpDirectives
+}
+
 func (g *cmdGlobal) cmpInstanceNamesFromRemote(toComplete string) ([]string, cobra.ShellCompDirective) {
 	results := []string{}
 
