@@ -12,13 +12,13 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/lxc/incus/client"
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/internal/instance"
-	"github.com/lxc/incus/shared/api"
-	config "github.com/lxc/incus/shared/cliconfig"
-	"github.com/lxc/incus/shared/units"
+	"github.com/lxc/incus/v6/client"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/internal/instance"
+	"github.com/lxc/incus/v6/shared/api"
+	config "github.com/lxc/incus/v6/shared/cliconfig"
+	"github.com/lxc/incus/v6/shared/units"
 )
 
 type column struct {
@@ -107,6 +107,7 @@ Pre-defined column shorthand chars:
   S - Number of snapshots
   t - Type (persistent or ephemeral)
   u - CPU usage (in seconds)
+  U - Started date
   L - Location of the instance (e.g. its cluster member)
   f - Base Image Fingerprint (short)
   F - Base Image Fingerprint (long)
@@ -586,6 +587,7 @@ func (c *cmdList) parseColumns(clustered bool) ([]column, bool, error) {
 		's': {i18n.G("STATE"), c.statusColumnData, false, false},
 		't': {i18n.G("TYPE"), c.typeColumnData, false, false},
 		'u': {i18n.G("CPU USAGE"), c.cpuUsageSecondsColumnData, true, false},
+		'U': {i18n.G("STARTED AT"), c.startedColumnData, true, false},
 	}
 
 	// Add project column if --all-projects flag specified and
@@ -927,6 +929,14 @@ func (c *cmdList) CreatedColumnData(cInfo api.InstanceFull) string {
 	return ""
 }
 
+func (c *cmdList) startedColumnData(cInfo api.InstanceFull) string {
+	if cInfo.State != nil && !cInfo.State.StartedAt.IsZero() {
+		return cInfo.State.StartedAt.Local().Format(dateLayout)
+	}
+
+	return ""
+}
+
 func (c *cmdList) LastUsedColumnData(cInfo api.InstanceFull) string {
 	if !cInfo.LastUsedAt.IsZero() {
 		return cInfo.LastUsedAt.Local().Format(dateLayout)
