@@ -20,6 +20,11 @@ type cmdNetworkZone struct {
 	global *cmdGlobal
 }
 
+type networkZoneColumn struct {
+	Name string
+	Data func(api.NetworkZone) string
+}
+
 func (c *cmdNetworkZone) Command() *cobra.Command {
 	cmd := &cobra.Command{}
 	cmd.Use = usage("zone")
@@ -75,6 +80,7 @@ type cmdNetworkZoneList struct {
 
 	flagFormat      string
 	flagAllProjects bool
+	flagColumns     string
 }
 
 func (c *cmdNetworkZoneList) Command() *cobra.Command {
@@ -82,11 +88,31 @@ func (c *cmdNetworkZoneList) Command() *cobra.Command {
 	cmd.Use = usage("list", i18n.G("[<remote>:]"))
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List available network zoneS")
-	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G("List available network zone"))
+	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
+		`List available network zone
+
+Default column layout: nDSdus
+
+== Columns ==
+The -c option takes a comma separated list of arguments that control
+which network zone attributes to output when displaying in table or csv
+format.
+
+Column arguments are either pre-defined shorthand chars (see below),
+or (extended) config keys.
+
+Commas between consecutive shorthand chars are optional.
+
+Pre-defined column shorthand chars:
+  d - Description
+  e - Project name
+  n - Name
+  u - Used by`))
 
 	cmd.RunE = c.Run
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
 	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("Display network zones from all projects"))
+	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultNetworkZoneColumns, i18n.G("Columns")+"``")
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
@@ -99,6 +125,57 @@ func (c *cmdNetworkZoneList) Command() *cobra.Command {
 	return cmd
 }
 
+const defaultNetworkZoneColumns = "ndu"
+
+func (c *cmdNetworkZoneList) parseColumns() ([]networkZoneColumn, error) {
+	columnsShorthandMap := map[rune]networkZoneColumn{
+		'e': {i18n.G("PROJECT"), c.projectColumnData},
+		'n': {i18n.G("NAME"), c.networkZoneNameColumnData},
+		'd': {i18n.G("DESCRIPTION"), c.descriptionColumnData},
+		'u': {i18n.G("USED BY"), c.usedByColumnData},
+	}
+
+	if c.flagColumns == defaultNetworkZoneColumns && c.flagAllProjects {
+		c.flagColumns = "endu"
+	}
+
+	columnList := strings.Split(c.flagColumns, ",")
+	columns := []networkZoneColumn{}
+
+	for _, columnEntry := range columnList {
+		if columnEntry == "" {
+			return nil, fmt.Errorf(i18n.G("Empty column entry (redundant, leading or trailing command) in '%s'"), c.flagColumns)
+		}
+
+		for _, columnRune := range columnEntry {
+			column, ok := columnsShorthandMap[columnRune]
+			if !ok {
+				return nil, fmt.Errorf(i18n.G("Unknown column shorthand char '%c' in '%s'"), columnRune, columnEntry)
+			}
+
+			columns = append(columns, column)
+		}
+	}
+
+	return columns, nil
+}
+
+func (c *cmdNetworkZoneList) projectColumnData(networkZone api.NetworkZone) string {
+	return networkZone.Project
+}
+
+func (c *cmdNetworkZoneList) networkZoneNameColumnData(networkZone api.NetworkZone) string {
+	return networkZone.Name
+}
+
+func (c *cmdNetworkZoneList) descriptionColumnData(networkZone api.NetworkZone) string {
+	return networkZone.Description
+}
+
+func (c *cmdNetworkZoneList) usedByColumnData(networkZone api.NetworkZone) string {
+	return fmt.Sprintf("%d", len(networkZone.UsedBy))
+}
+
 func (c *cmdNetworkZoneList) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 0, 1)
@@ -137,32 +214,28 @@ func (c *cmdNetworkZoneList) Run(cmd *cobra.Command, args []string) error {
 		}
 	}
 
+	// Parse column flags.
+	columns, err := c.parseColumns()
+	if err != nil {
+		return err
+	}
+
 	data := [][]string{}
 	for _, zone := range zones {
-		strUsedBy := fmt.Sprintf("%d", len(zone.UsedBy))
-		details := []string{
-			zone.Name,
-			zone.Description,
-			strUsedBy,
+
+		line := []string{}
+		for _, column := range columns {
+			line = append(line, column.Data(zone))
 		}
 
-		if c.flagAllProjects {
-			details = append([]string{zone.Project}, details...)
-		}
-
-		data = append(data, details)
+		data = append(data, line)
 	}
 
 	sort.Sort(cli.SortColumnsNaturally(data))
 
-	header := []string{
-		i18n.G("NAME"),
-		i18n.G("DESCRIPTION"),
-		i18n.G("USED BY"),
-	}
-
-	if c.flagAllProjects {
-		header = append([]string{i18n.G("PROJECT")}, header...)
+	header := []string{}
+	for _, column := range columns {
+		header = append(header, column.Name)
 	}
 
 	return cli.RenderTable(c.flagFormat, header, data, zones)
