@@ -12,12 +12,17 @@ import (
 	"github.com/spf13/cobra"
 	"gopkg.in/yaml.v2"
 
-	cli "github.com/lxc/incus/internal/cmd"
-	"github.com/lxc/incus/internal/i18n"
-	"github.com/lxc/incus/shared/api"
-	"github.com/lxc/incus/shared/termios"
+	cli "github.com/lxc/incus/v6/internal/cmd"
+	"github.com/lxc/incus/v6/internal/i18n"
+	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/termios"
 )
 
+type profileColumn struct {
+	Name string
+	Data func(api.Profile) string
+}
+
 type cmdProfile struct {
 	global *cmdGlobal
 }
@@ -351,6 +356,11 @@ func (c *cmdProfileCreate) Command() *cobra.Command {
 	cmd.Short = i18n.G("Create profiles")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
 		`Create profiles`))
+	cmd.Example = cli.FormatSection("", i18n.G(`incus profile create p1
+    Create a profile named p1
+
+incus profile create p1 < config.yaml
+    Create a profile named p1 with configuration from config.yaml`))
 
 	cmd.RunE = c.Run
 
@@ -366,12 +376,27 @@ func (c *cmdProfileCreate) Command() *cobra.Command {
 }
 
 func (c *cmdProfileCreate) Run(cmd *cobra.Command, args []string) error {
+	var stdinData api.ProfilePut
+
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 1, 1)
 	if exit {
 		return err
 	}
 
+	// If stdin isn't a terminal, read text from it
+	if !termios.IsTerminal(getStdinFd()) {
+		contents, err := io.ReadAll(os.Stdin)
+		if err != nil {
+			return err
+		}
+
+		err = yaml.Unmarshal(contents, &stdinData)
+		if err != nil {
+			return err
+		}
+	}
+
 	// Parse remote
 	resources, err := c.global.ParseServers(args[0])
 	if err != nil {
@@ -387,6 +412,7 @@ func (c *cmdProfileCreate) Run(cmd *cobra.Command, args []string) error {
 	// Create the profile
 	profile := api.ProfilesPost{}
 	profile.Name = resource.name
+	profile.ProfilePut = stdinData
 
 	err = resource.server.CreateProfile(profile)
 	if err != nil {
@@ -669,9 +695,11 @@ func (c *cmdProfileGet) Run(cmd *cobra.Command, args []string) error {
 
 // List.
 type cmdProfileList struct {
-	global     *cmdGlobal
-	profile    *cmdProfile
-	flagFormat string
+	global          *cmdGlobal
+	profile         *cmdProfile
+	flagFormat      string
+	flagColumns     string
+	flagAllProjects bool
 }
 
 func (c *cmdProfileList) Command() *cobra.Command {
@@ -680,10 +708,23 @@ func (c *cmdProfileList) Command() *cobra.Command {
 	cmd.Aliases = []string{"ls"}
 	cmd.Short = i18n.G("List profiles")
 	cmd.Long = cli.FormatSection(i18n.G("Description"), i18n.G(
-		`List profiles`))
+		`List profiles
+
+The -c option takes a (optionally comma-separated) list of arguments
+that control which image attributes to output when displaying in table
+or csv format.
+
+Default column layout is: ndu
+
+Column shorthand chars:
+n - Profile Name
+d - Description
+u - Used By`))
 
 	cmd.RunE = c.Run
+	cmd.Flags().StringVarP(&c.flagColumns, "columns", "c", defaultProfileColumns, i18n.G("Columns")+"``")
 	cmd.Flags().StringVarP(&c.flagFormat, "format", "f", "table", i18n.G("Format (csv|json|table|yaml|compact)")+"``")
+	cmd.Flags().BoolVar(&c.flagAllProjects, "all-projects", false, i18n.G("Display profiles from all projects"))
 
 	cmd.ValidArgsFunction = func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		if len(args) == 0 {
@@ -696,6 +737,61 @@ func (c *cmdProfileList) Command() *cobra.Command {
 	return cmd
 }
 
+const defaultProfileColumns = "ndu"
+const defaultProfileColumnsAllProjects = "endu"
+
+func (c *cmdProfileList) parseColumns() ([]profileColumn, error) {
+	columnsShorthandMap := map[rune]profileColumn{
+		'n': {i18n.G("NAME"), c.profileNameColumnData},
+		'e': {i18n.G("PROJECT"), c.projectNameColumnData},
+		'd': {i18n.G("DESCRIPTION"), c.descriptionColumnData},
+		'u': {i18n.G("USED BY"), c.usedByColumnData},
+	}
+
+	// Add project column if --all-projects flag specified and no custom column was passed.
+	if c.flagAllProjects {
+		if c.flagColumns == defaultProfileColumns {
+			c.flagColumns = defaultProfileColumnsAllProjects
+		}
+	}
+
+	columnList := strings.Split(c.flagColumns, ",")
+	columns := []profileColumn{}
+
+	for _, columnEntry := range columnList {
+		if columnEntry == "" {
+			return nil, fmt.Errorf(i18n.G("Empty column entry (redundant, leading or trailing command) in '%s'"), c.flagColumns)
+		}
+
+		for _, columnRune := range columnEntry {
+			column, ok := columnsShorthandMap[columnRune]
+			if !ok {
+				return nil, fmt.Errorf(i18n.G("Unknown column shorthand char '%c' in '%s'"), columnRune, columnEntry)
+			}
+
+			columns = append(columns, column)
+		}
+	}
+
+	return columns, nil
+}
+
+func (c *cmdProfileList) profileNameColumnData(profile api.Profile) string {
+	return profile.Name
+}
+
+func (c *cmdProfileList) descriptionColumnData(profile api.Profile) string {
+	return profile.Description
+}
+
+func (c *cmdProfileList) projectNameColumnData(profile api.Profile) string {
+	return profile.Project
+}
+
+func (c *cmdProfileList) usedByColumnData(profile api.Profile) string {
+	return fmt.Sprintf("%d", len(profile.UsedBy))
+}
+
 func (c *cmdProfileList) Run(cmd *cobra.Command, args []string) error {
 	// Quick checks.
 	exit, err := c.global.CheckArgs(cmd, args, 0, 1)
@@ -703,6 +799,10 @@ func (c *cmdProfileList) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	if c.global.flagProject != "" && c.flagAllProjects {
+		return fmt.Errorf(i18n.G("Can't specify --project with --all-projects"))
+	}
+
 	// Parse remote
 	remote := ""
 	if len(args) > 0 {
@@ -717,23 +817,40 @@ func (c *cmdProfileList) Run(cmd *cobra.Command, args []string) error {
 	resource := resources[0]
 
 	// List profiles
-	profiles, err := resource.server.GetProfiles()
+	var profiles []api.Profile
+	if c.flagAllProjects {
+		profiles, err = resource.server.GetProfilesAllProjects()
+		if err != nil {
+			return err
+		}
+	} else {
+		profiles, err = resource.server.GetProfiles()
+		if err != nil {
+			return err
+		}
+	}
+
+	columns, err := c.parseColumns()
 	if err != nil {
 		return err
 	}
 
 	data := [][]string{}
 	for _, profile := range profiles {
-		strUsedBy := fmt.Sprintf("%d", len(profile.UsedBy))
-		data = append(data, []string{profile.Name, profile.Description, strUsedBy})
+		line := []string{}
+		for _, column := range columns {
+			line = append(line, column.Data(profile))
+		}
+
+		data = append(data, line)
 	}
 
 	sort.Sort(cli.SortColumnsNaturally(data))
 
-	header := []string{
-		i18n.G("NAME"),
-		i18n.G("DESCRIPTION"),
-		i18n.G("USED BY")}
+	header := []string{}
+	for _, column := range columns {
+		header = append(header, column.Name)
+	}
 
 	return cli.RenderTable(c.flagFormat, header, data, profiles)
 }
