@@ -54,10 +54,10 @@ var apiInternal = []APIEndpoint{
 	internalClusterHandoverCmd,
 	internalClusterRaftNodeCmd,
 	internalClusterRebalanceCmd,
-	internalClusterHealCmd,
 	internalContainerOnStartCmd,
 	internalContainerOnStopCmd,
 	internalContainerOnStopNSCmd,
+	internalVirtualMachineOnResizeCmd,
 	internalGarbageCollectorCmd,
 	internalImageOptimizeCmd,
 	internalImageRefreshCmd,
@@ -98,6 +98,12 @@ var internalContainerOnStopCmd = APIEndpoint{
 	Get: APIEndpointAction{Handler: internalContainerOnStop, AccessHandler: allowPermission(auth.ObjectTypeServer, auth.EntitlementCanEdit)},
 }
 
+var internalVirtualMachineOnResizeCmd = APIEndpoint{
+	Path: "virtual-machines/{instanceRef}/onresize",
+
+	Get: APIEndpointAction{Handler: internalVirtualMachineOnResize, AccessHandler: allowPermission(auth.ObjectTypeServer, auth.EntitlementCanEdit)},
+}
+
 var internalSQLCmd = APIEndpoint{
 	Path: "sql",
 
@@ -401,6 +407,56 @@ func internalContainerOnStop(d *Daemon, r *http.Request) response.Response {
 	return response.EmptySyncResponse
 }
 
+func internalVirtualMachineOnResize(d *Daemon, r *http.Request) response.Response {
+	s := d.State()
+
+	// Get the instance ID.
+	instanceID, err := strconv.Atoi(mux.Vars(r)["instanceRef"])
+	if err != nil {
+		return response.BadRequest(err)
+	}
+
+	// Get the devices list.
+	devices := request.QueryParam(r, "devices")
+	if devices == "" {
+		return response.BadRequest(fmt.Errorf("Resize hook requires a list of devices"))
+	}
+
+	// Load by ID.
+	inst, err := instance.LoadByID(s, instanceID)
+	if err != nil {
+		return response.SmartError(err)
+	}
+
+	// Update the local instance.
+	for _, dev := range strings.Split(devices, ",") {
+		fields := strings.SplitN(dev, ":", 2)
+		if len(fields) != 2 {
+			return response.BadRequest(fmt.Errorf("Invalid device/size tuple: %s", dev))
+		}
+
+		size, err := strconv.ParseInt(fields[1], 16, 64)
+		if err != nil {
+			return response.BadRequest(err)
+		}
+
+		runConf := deviceConfig.RunConfig{}
+		runConf.Mounts = []deviceConfig.MountEntryItem{
+			{
+				DevName: fields[0],
+				Size:    size,
+			},
+		}
+
+		err = inst.DeviceEventHandler(&runConf)
+		if err != nil {
+			return response.InternalError(err)
+		}
+	}
+
+	return response.EmptySyncResponse
+}
+
 // Perform a database dump.
 func internalSQLGet(d *Daemon, r *http.Request) response.Response {
 	s := d.State()
@@ -654,7 +710,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 
 	if backupConf.Pool == nil {
 		// We don't know what kind of storage type the pool is.
-		return fmt.Errorf(`No storage pool struct in the backup file found. The storage pool needs to be recovered manually`)
+		return fmt.Errorf("No storage pool struct in the backup file found. The storage pool needs to be recovered manually")
 	}
 
 	// Try to retrieve the storage pool the instance supposedly lives on.
@@ -758,7 +814,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 		return err
 	}
 
-	_, instOp, cleanup, err := instance.CreateInternal(s, *instDBArgs, true, true)
+	_, instOp, cleanup, err := instance.CreateInternal(s, *instDBArgs, nil, true, true)
 	if err != nil {
 		return fmt.Errorf("Failed creating instance record: %w", err)
 	}
@@ -872,7 +928,7 @@ func internalImportFromBackup(ctx context.Context, s *state.State, projectName s
 			Name:         snapInstName,
 			Profiles:     profiles,
 			Stateful:     snap.Stateful,
-		}, true, true)
+		}, nil, true, true)
 		if err != nil {
 			return fmt.Errorf("Failed creating instance snapshot record %q: %w", snap.Name, err)
 		}
