@@ -138,8 +138,13 @@ func instancePut(d *Daemon, r *http.Request) response.Response {
 				return err
 			}
 
+			profileDevices, err := cluster.GetDevices(ctx, tx.Tx(), "profile")
+			if err != nil {
+				return err
+			}
+
 			for _, profile := range profiles {
-				apiProfile, err := profile.ToAPI(ctx, tx.Tx())
+				apiProfile, err := profile.ToAPI(ctx, tx.Tx(), profileDevices)
 				if err != nil {
 					return err
 				}
@@ -155,6 +160,7 @@ func instancePut(d *Daemon, r *http.Request) response.Response {
 
 		// Update container configuration
 		do = func(op *operations.Operation) error {
+			inst.SetOperation(op)
 			defer unlock()
 
 			args := db.InstanceArgs{
@@ -181,7 +187,7 @@ func instancePut(d *Daemon, r *http.Request) response.Response {
 		do = func(op *operations.Operation) error {
 			defer unlock()
 
-			return instanceSnapRestore(s, projectName, name, configRaw.Restore, configRaw.Stateful)
+			return instanceSnapRestore(s, projectName, name, configRaw.Restore, configRaw.Stateful, op)
 		}
 
 		opType = operationtype.SnapshotRestore
@@ -199,7 +205,7 @@ func instancePut(d *Daemon, r *http.Request) response.Response {
 	return operations.OperationResponse(op)
 }
 
-func instanceSnapRestore(s *state.State, projectName string, name string, snap string, stateful bool) error {
+func instanceSnapRestore(s *state.State, projectName string, name string, snap string, stateful bool, op *operations.Operation) error {
 	// normalize snapshot name
 	if !internalInstance.IsSnapshot(snap) {
 		snap = name + internalInstance.SnapshotDelimiter + snap
@@ -210,6 +216,8 @@ func instanceSnapRestore(s *state.State, projectName string, name string, snap s
 		return err
 	}
 
+	inst.SetOperation(op)
+
 	source, err := instance.LoadByProjectAndName(s, projectName, snap)
 	if err != nil {
 		switch {
@@ -219,6 +227,7 @@ func instanceSnapRestore(s *state.State, projectName string, name string, snap s
 			return err
 		}
 	}
+	source.SetOperation(op)
 
 	// Generate a new `volatile.uuid.generation` to differentiate this instance restored from a snapshot from the original instance.
 	source.LocalConfig()["volatile.uuid.generation"] = uuid.New().String()
