@@ -5,8 +5,8 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/lxc/incus/client"
-	"github.com/lxc/incus/shared/util"
+	"github.com/lxc/incus/v6/client"
+	"github.com/lxc/incus/v6/shared/util"
 )
 
 type srcManual struct{}
