@@ -7,12 +7,15 @@ import (
 	"strings"
 
 	"github.com/lxc/incus/v6/internal/server/cgroup"
+	"github.com/lxc/incus/v6/internal/server/instance/drivers/edk2"
 	"github.com/lxc/incus/v6/internal/server/instance/instancetype"
 	"github.com/lxc/incus/v6/internal/server/project"
+	storageDrivers "github.com/lxc/incus/v6/internal/server/storage/drivers"
 	"github.com/lxc/incus/v6/internal/server/sys"
 	localUtil "github.com/lxc/incus/v6/internal/server/util"
 	internalUtil "github.com/lxc/incus/v6/internal/util"
 	"github.com/lxc/incus/v6/shared/api"
+	"github.com/lxc/incus/v6/shared/osarch"
 	"github.com/lxc/incus/v6/shared/util"
 )
 
@@ -26,6 +29,7 @@ type instance interface {
 	RunPath() string
 	Path() string
 	DevicesPath() string
+	IsPrivileged() bool
 }
 
 // InstanceProfileName returns the instance's AppArmor profile name.
@@ -186,6 +190,7 @@ func instanceProfile(sysOS *sys.OS, inst instance, extraBinaries []string) (stri
 			"nesting":             util.IsTrue(inst.ExpandedConfig()["security.nesting"]),
 			"raw":                 rawContent,
 			"unprivileged":        util.IsFalseOrEmpty(inst.ExpandedConfig()["security.privileged"]) || sysOS.RunningInUserNS,
+			"zfs_delegation":      !inst.IsPrivileged() && storageDrivers.ZFSSupportsDelegation() && util.PathExists("/dev/zfs"),
 		})
 		if err != nil {
 			return "", err
@@ -197,14 +202,31 @@ func instanceProfile(sysOS *sys.OS, inst instance, extraBinaries []string) (stri
 			return "", err
 		}
 
-		ovmfPath := "/usr/share/OVMF"
-		if os.Getenv("INCUS_OVMF_PATH") != "" {
-			ovmfPath = os.Getenv("INCUS_OVMF_PATH")
-		}
+		var edk2Paths []string
 
-		ovmfPath, err = filepath.EvalSymlinks(ovmfPath)
-		if err != nil {
-			return "", err
+		edk2Path := edk2.GetenvEdk2Path()
+		if edk2Path != "" {
+			edk2Path, err := filepath.EvalSymlinks(edk2Path)
+			if err != nil {
+				return "", err
+			}
+
+			edk2Paths = append(edk2Paths, edk2Path)
+		} else {
+			arch, err := osarch.ArchitectureGetLocalID()
+
+			if err == nil {
+				for _, installation := range edk2.GetArchitectureInstallations(arch) {
+					if util.PathExists(installation.Path) {
+						edk2Path, err := filepath.EvalSymlinks(installation.Path)
+						if err != nil {
+							return "", err
+						}
+
+						edk2Paths = append(edk2Paths, edk2Path)
+					}
+				}
+			}
 		}
 
 		agentPath := ""
@@ -221,9 +243,24 @@ func instanceProfile(sysOS *sys.OS, inst instance, extraBinaries []string) (stri
 			execPath = execPathFull
 		}
 
+		// Extra (read-only) config paths.
+		extraConfig := []string{}
+		if util.PathExists("/etc/ceph") {
+			extraConfig = append(extraConfig, "/etc/ceph")
+
+			// See if default config points to another path.
+			if util.PathExists("/etc/ceph/ceph.conf") {
+				target, err := filepath.EvalSymlinks("/etc/ceph/ceph.conf")
+				if err == nil && target != "/etc/ceph/ceph.conf" {
+					extraConfig = append(extraConfig, filepath.Dir(target))
+				}
+			}
+		}
+
 		err = qemuProfileTpl.Execute(sb, map[string]any{
 			"devicesPath":    inst.DevicesPath(),
 			"exePath":        execPath,
+			"extra_config":   extraConfig,
 			"extra_binaries": extraBinaries,
 			"libraryPath":    strings.Split(os.Getenv("LD_LIBRARY_PATH"), ":"),
 			"logPath":        inst.LogPath(),
@@ -231,7 +268,7 @@ func instanceProfile(sysOS *sys.OS, inst instance, extraBinaries []string) (stri
 			"name":           InstanceProfileName(inst),
 			"path":           path,
 			"raw":            rawContent,
-			"ovmfPath":       ovmfPath,
+			"edk2Paths":      edk2Paths,
 			"agentPath":      agentPath,
 		})
 		if err != nil {
