@@ -77,16 +77,23 @@ type InstanceFilter struct {
 }
 
 // ToAPI converts the database Instance to API type.
-func (i *Instance) ToAPI(ctx context.Context, tx *sql.Tx) (*api.Instance, error) {
+func (i *Instance) ToAPI(ctx context.Context, tx *sql.Tx, instanceDevices map[int][]Device, profileDevices map[int][]Device) (*api.Instance, error) {
 	profiles, err := GetInstanceProfiles(ctx, tx, i.ID)
 	if err != nil {
 		return nil, err
 	}
 
+	if profileDevices == nil {
+		profileDevices, err = GetDevices(ctx, tx, "profile")
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	apiProfiles := make([]api.Profile, 0, len(profiles))
 	profileNames := make([]string, 0, len(profiles))
 	for _, p := range profiles {
-		apiProfile, err := p.ToAPI(ctx, tx)
+		apiProfile, err := p.ToAPI(ctx, tx, profileDevices)
 		if err != nil {
 			return nil, err
 		}
@@ -95,9 +102,18 @@ func (i *Instance) ToAPI(ctx context.Context, tx *sql.Tx) (*api.Instance, error)
 		profileNames = append(profileNames, p.Name)
 	}
 
-	devices, err := GetInstanceDevices(ctx, tx, i.ID)
-	if err != nil {
-		return nil, err
+	var devices map[string]Device
+	if instanceDevices != nil {
+		devices = map[string]Device{}
+
+		for _, dev := range instanceDevices[i.ID] {
+			devices[dev.Name] = dev
+		}
+	} else {
+		devices, err = GetInstanceDevices(ctx, tx, i.ID)
+		if err != nil {
+			return nil, err
+		}
 	}
 
 	apiDevices := DevicesToAPI(devices)
