@@ -61,7 +61,7 @@ func (c *ClusterTx) GetProfile(ctx context.Context, project, name string) (int64
 	profile := profiles[0]
 	id := int64(profile.ID)
 
-	result, err := profile.ToAPI(ctx, c.tx)
+	result, err := profile.ToAPI(ctx, c.tx, nil)
 	if err != nil {
 		return -1, nil, err
 	}
@@ -78,8 +78,14 @@ func (c *ClusterTx) GetProfiles(ctx context.Context, projectName string, profile
 		return nil, err
 	}
 
+	// Get all the profile devices.
+	profileDevices, err := cluster.GetDevices(ctx, c.Tx(), "profile")
+	if err != nil {
+		return nil, err
+	}
+
 	for i, profile := range dbProfiles {
-		apiProfile, err := profile.ToAPI(ctx, c.tx)
+		apiProfile, err := profile.ToAPI(ctx, c.tx, profileDevices)
 		if err != nil {
 			return nil, err
 		}
