@@ -29,7 +29,6 @@ import (
 	firewallDrivers "github.com/lxc/incus/v6/internal/server/firewall/drivers"
 	"github.com/lxc/incus/v6/internal/server/ip"
 	"github.com/lxc/incus/v6/internal/server/network/acl"
-	"github.com/lxc/incus/v6/internal/server/network/ovs"
 	"github.com/lxc/incus/v6/internal/server/project"
 	localUtil "github.com/lxc/incus/v6/internal/server/util"
 	"github.com/lxc/incus/v6/internal/server/warnings"
@@ -628,9 +627,9 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 	// Create the bridge interface if doesn't exist.
 	if !n.isRunning() {
 		if n.config["bridge.driver"] == "openvswitch" {
-			vswitch, err := ovs.NewVSwitch()
-			if err != nil || !vswitch.Installed() {
-				return fmt.Errorf("Open vSwitch isn't installed on this system")
+			vswitch, err := n.state.OVS()
+			if err != nil {
+				return fmt.Errorf("Couldn't connect to OpenVSwitch: %v", err)
 			}
 
 			// Add and configure the interface in one operation to reduce the number of executions and
@@ -733,7 +732,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 			revert.Add(func() { _ = dummy.Delete() })
 			err = dummy.SetUp()
 			if err == nil {
-				_ = AttachInterface(n.name, fmt.Sprintf("%s-mtu", n.name))
+				_ = AttachInterface(n.state, n.name, fmt.Sprintf("%s-mtu", n.name))
 			}
 		}
 	}
@@ -818,7 +817,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 				return fmt.Errorf("Only unconfigured network interfaces can be bridged")
 			}
 
-			err = AttachInterface(n.name, entry)
+			err = AttachInterface(n.state, n.name, entry)
 			if err != nil {
 				return err
 			}
@@ -1320,7 +1319,7 @@ func (n *bridge) setup(oldConfig map[string]string) error {
 		}
 
 		// Bridge it and bring up.
-		err = AttachInterface(n.name, tunName)
+		err = AttachInterface(n.state, n.name, tunName)
 		if err != nil {
 			return err
 		}
@@ -1535,7 +1534,7 @@ func (n *bridge) Stop() error {
 
 	// Destroy the bridge interface
 	if n.config["bridge.driver"] == "openvswitch" {
-		vswitch, err := ovs.NewVSwitch()
+		vswitch, err := n.state.OVS()
 		if err != nil {
 			return err
 		}
@@ -1673,7 +1672,7 @@ func (n *bridge) Update(newNetwork api.NetworkPut, targetNode string, clientType
 				}
 
 				if !slices.Contains(devices, dev) && InterfaceExists(ifName) {
-					err = DetachInterface(n.name, ifName)
+					err = DetachInterface(n.state, n.name, ifName)
 					if err != nil {
 						return err
 					}
