@@ -6,7 +6,6 @@ import (
 	"crypto/x509"
 	"encoding/pem"
 	"fmt"
-	"os"
 	"reflect"
 	"runtime"
 	"strings"
@@ -17,21 +16,13 @@ import (
 	ovsdbClient "github.com/ovn-org/libovsdb/client"
 	ovsdbModel "github.com/ovn-org/libovsdb/model"
 
-	"github.com/lxc/incus/v6/internal/linux"
 	ovnNB "github.com/lxc/incus/v6/internal/server/network/ovn/schema/ovn-nb"
-	"github.com/lxc/incus/v6/shared/subprocess"
 )
 
 // NB client.
 type NB struct {
 	client ovsdbClient.Client
 	cookie ovsdbClient.MonitorCookie
-
-	// For nbctl command calls.
-	dbAddr        string
-	sslCACert     string
-	sslClientCert string
-	sslClientKey  string
 }
 
 var nb *NB
@@ -43,9 +34,7 @@ func NewNB(dbAddr string, sslCACert string, sslClientCert string, sslClientKey s
 	}
 
 	// Create the NB struct.
-	client := &NB{
-		dbAddr: dbAddr,
-	}
+	client := &NB{}
 
 	// Prepare the OVSDB client.
 	dbSchema, err := ovnNB.FullDatabaseModel()
@@ -55,6 +44,7 @@ func NewNB(dbAddr string, sslCACert string, sslClientCert string, sslClientKey s
 
 	// Add some missing indexes.
 	dbSchema.SetIndexes(map[string][]ovsdbModel.ClientIndex{
+		"Load_Balancer":       {{Columns: []ovsdbModel.ColumnKey{{Column: "name"}}}},
 		"Logical_Router":      {{Columns: []ovsdbModel.ColumnKey{{Column: "name"}}}},
 		"Logical_Switch":      {{Columns: []ovsdbModel.ColumnKey{{Column: "name"}}}},
 		"Logical_Switch_Port": {{Columns: []ovsdbModel.ColumnKey{{Column: "name"}}}},
@@ -139,11 +129,6 @@ func NewNB(dbAddr string, sslCACert string, sslClientCert string, sslClientKey s
 
 		// Add the TLS config to the client.
 		options = append(options, ovsdbClient.WithTLSConfig(tlsConfig))
-
-		// Fill the fields need for the CLI calls.
-		client.sslCACert = sslCACert
-		client.sslClientCert = sslClientCert
-		client.sslClientKey = sslClientKey
 	}
 
 	// Connect to OVSDB.
@@ -189,6 +174,9 @@ func (o *NB) get(ctx context.Context, m ovsdbModel.Model) error {
 
 	// Check if one of the broken types.
 	switch m.(type) {
+	case *ovnNB.LoadBalancer:
+		s := []ovnNB.LoadBalancer{}
+		collection = &s
 	case *ovnNB.LogicalRouter:
 		s := []ovnNB.LogicalRouter{}
 		collection = &s
@@ -226,49 +214,3 @@ func (o *NB) get(ctx context.Context, m ovsdbModel.Model) error {
 	reflect.ValueOf(m).Elem().Set(rVal.Index(0))
 	return nil
 }
-
-// nbctl executes ovn-nbctl with arguments to connect to wrapper's northbound database.
-func (o *NB) nbctl(extraArgs ...string) (string, error) {
-	// Figure out args.
-	args := []string{"--timeout=10", "--db", o.dbAddr}
-
-	// Handle SSL args.
-	files := []*os.File{}
-	if strings.Contains(o.dbAddr, "ssl:") {
-		// Handle client certificate.
-		clientCertFile, err := linux.CreateMemfd([]byte(o.sslClientCert))
-		if err != nil {
-			return "", err
-		}
-
-		defer clientCertFile.Close()
-		files = append(files, clientCertFile)
-
-		// Handle client key.
-		clientKeyFile, err := linux.CreateMemfd([]byte(o.sslClientKey))
-		if err != nil {
-			return "", err
-		}
-
-		defer clientKeyFile.Close()
-		files = append(files, clientKeyFile)
-
-		// Handle CA certificate.
-		caCertFile, err := linux.CreateMemfd([]byte(o.sslCACert))
-		if err != nil {
-			return "", err
-		}
-
-		defer caCertFile.Close()
-		files = append(files, caCertFile)
-
-		args = append(args,
-			"-c", "/proc/self/fd/3",
-			"-p", "/proc/self/fd/4",
-			"-C", "/proc/self/fd/5",
-		)
-	}
-
-	args = append(args, extraArgs...)
-	return subprocess.RunCommandInheritFds(context.Background(), files, "ovn-nbctl", args...)
-}
