@@ -9,7 +9,6 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
-	"time"
 
 	internalInstance "github.com/lxc/incus/v6/internal/instance"
 	"github.com/lxc/incus/v6/internal/linux"
@@ -133,7 +132,17 @@ func (d *lvm) volumeGroupExists(vgName string) (bool, []string, error) {
 
 // volumeGroupExtentSize gets the volume group's physical extent size in bytes.
 func (d *lvm) volumeGroupExtentSize(vgName string) (int64, error) {
-	output, err := subprocess.RunCommand("vgs", "--noheadings", "--nosuffix", "--units", "b", "-o", "vg_extent_size", vgName)
+	// Look for cached value.
+	lvmExtentSizeMu.Lock()
+	defer lvmExtentSizeMu.Unlock()
+
+	if lvmExtentSize == nil {
+		lvmExtentSize = map[string]int64{}
+	} else if lvmExtentSize[d.name] > 0 {
+		return lvmExtentSize[d.name], nil
+	}
+
+	output, err := subprocess.TryRunCommand("vgs", "--noheadings", "--nosuffix", "--units", "b", "-o", "vg_extent_size", vgName)
 	if err != nil {
 		if d.isLVMNotFoundExitError(err) {
 			return -1, api.StatusErrorf(http.StatusNotFound, "LVM volume group not found")
@@ -143,12 +152,19 @@ func (d *lvm) volumeGroupExtentSize(vgName string) (int64, error) {
 	}
 
 	output = strings.TrimSpace(output)
-	return strconv.ParseInt(output, 10, 64)
+	val, err := strconv.ParseInt(output, 10, 64)
+	if err != nil {
+		return -1, err
+	}
+
+	lvmExtentSize[d.name] = val
+
+	return val, nil
 }
 
 // countLogicalVolumes gets the count of volumes (both normal and thin) in a volume group.
 func (d *lvm) countLogicalVolumes(vgName string) (int, error) {
-	output, err := subprocess.RunCommand("vgs", "--noheadings", "-o", "lv_count", vgName)
+	output, err := subprocess.TryRunCommand("vgs", "--noheadings", "-o", "lv_count", vgName)
 	if err != nil {
 		if d.isLVMNotFoundExitError(err) {
 			return -1, api.StatusErrorf(http.StatusNotFound, "LVM volume group not found")
@@ -163,7 +179,7 @@ func (d *lvm) countLogicalVolumes(vgName string) (int, error) {
 
 // countThinVolumes gets the count of thin volumes in a thin pool.
 func (d *lvm) countThinVolumes(vgName, poolName string) (int, error) {
-	output, err := subprocess.RunCommand("lvs", "--noheadings", "-o", "thin_count", fmt.Sprintf("%s/%s", vgName, poolName))
+	output, err := subprocess.TryRunCommand("lvs", "--noheadings", "-o", "thin_count", fmt.Sprintf("%s/%s", vgName, poolName))
 	if err != nil {
 		if d.isLVMNotFoundExitError(err) {
 			return -1, api.StatusErrorf(http.StatusNotFound, "LVM volume group not found")
@@ -391,7 +407,7 @@ func (d *lvm) createLogicalVolume(vgName, thinPoolName string, vol Volume, makeT
 	if isRecent {
 		// Disable auto activation of volume on LVM versions that support it.
 		// Must be done after volume create so that zeroing and signature wiping can take place.
-		_, err := subprocess.RunCommand("lvchange", "--setactivationskip", "y", volDevPath)
+		_, err := subprocess.TryRunCommand("lvchange", "--setactivationskip", "y", volDevPath)
 		if err != nil {
 			return fmt.Errorf("Failed to set activation skip on LVM logical volume %q: %w", volDevPath, err)
 		}
@@ -433,6 +449,19 @@ func (d *lvm) createLogicalVolumeSnapshot(vgName string, srcVol Volume, snapVol
 	revert := revert.New()
 	defer revert.Fail()
 
+	// If clustered, we need to acquire exclusive write access for this operation.
+	if d.clustered && !makeThinLv {
+		parent, _, _ := api.GetParentAndSnapshotName(srcVol.Name())
+		parentVol := NewVolume(d, d.Name(), srcVol.volType, srcVol.contentType, parent, srcVol.config, srcVol.poolConfig)
+
+		release, err := d.acquireExclusive(parentVol)
+		if err != nil {
+			return "", err
+		}
+
+		defer release()
+	}
+
 	_, err = subprocess.TryRunCommand("lvcreate", args...)
 	if err != nil {
 		return "", err
@@ -450,6 +479,24 @@ func (d *lvm) createLogicalVolumeSnapshot(vgName string, srcVol Volume, snapVol
 	return targetVolDevPath, nil
 }
 
+// acquireExclusive switches a volume lock to exclusive mode.
+func (d *lvm) acquireExclusive(vol Volume) (func(), error) {
+	volDevPath := d.lvmDevPath(d.config["lvm.vg_name"], vol.volType, vol.contentType, vol.name)
+
+	if !d.clustered || !util.PathExists(volDevPath) {
+		return func() {}, nil
+	}
+
+	_, err := subprocess.TryRunCommand("lvchange", "--activate", "ey", "--ignoreactivationskip", volDevPath)
+	if err != nil {
+		return nil, fmt.Errorf("Failed to acquire exclusive lock on LVM logical volume %q: %w", volDevPath, err)
+	}
+
+	return func() {
+		_, _ = subprocess.TryRunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volDevPath)
+	}, nil
+}
+
 // removeLogicalVolume removes a logical volume.
 func (d *lvm) removeLogicalVolume(volDevPath string) error {
 	_, err := subprocess.TryRunCommand("lvremove", "-f", volDevPath)
@@ -778,9 +825,16 @@ func (d *lvm) activateVolume(vol Volume) (bool, error) {
 	}
 
 	if !util.PathExists(volDevPath) {
-		_, err := subprocess.RunCommand("lvchange", "--activate", "y", "--ignoreactivationskip", volDevPath)
-		if err != nil {
-			return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volDevPath, err)
+		if d.clustered {
+			_, err := subprocess.RunCommand("lvchange", "--activate", "sy", "--ignoreactivationskip", volDevPath)
+			if err != nil {
+				return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volDevPath, err)
+			}
+		} else {
+			_, err := subprocess.RunCommand("lvchange", "--activate", "y", "--ignoreactivationskip", volDevPath)
+			if err != nil {
+				return false, fmt.Errorf("Failed to activate LVM logical volume %q: %w", volDevPath, err)
+			}
 		}
 
 		d.logger.Debug("Activated logical volume", logger.Ctx{"volName": vol.Name(), "dev": volDevPath})
@@ -814,17 +868,7 @@ func (d *lvm) deactivateVolume(vol Volume) (bool, error) {
 
 	if util.PathExists(volDevPath) {
 		// Keep trying to deactivate a few times in case the device is still being flushed.
-		var err error
-		for i := 0; i < 20; i++ {
-			_, err = subprocess.RunCommand("lvchange", "--activate", "n", "--ignoreactivationskip", volDevPath)
-			if err == nil {
-				break
-			}
-
-			logger.Debug("Failed to deactivate LVM logical volume", logger.Ctx{"path": volDevPath, "attempt": i, "err": err})
-			time.Sleep(500 * time.Millisecond)
-		}
-
+		_, err := subprocess.TryRunCommand("lvchange", "--activate", "n", "--ignoreactivationskip", volDevPath)
 		if err != nil {
 			return false, fmt.Errorf("Failed to deactivate LVM logical volume %q: %w", volDevPath, err)
 		}
