@@ -5,7 +5,7 @@ package cliconfig
 import (
 	"fmt"
 
-	"github.com/lxc/incus/client"
+	"github.com/lxc/incus/v6/client"
 )
 
 func (c *Config) handleKeepAlive(remote Remote, name string, args *incus.ConnectionArgs) (incus.InstanceServer, error) {
